==> elasticloadbalancingv2-1.132.0-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/SslPolicy.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Elastic Load Balancing provides the following security policies for Application Load Balancers.
 * <p>
 * We recommend the Recommended policy for general use. You can
 * use the ForwardSecrecy policy if you require Forward Secrecy
 * (FS).
 * <p>
 * You can use one of the TLS policies to meet compliance and security
 * standards that require disabling certain TLS protocol versions, or to
 * support legacy clients that require deprecated ciphers.
 * <p>
 * @see https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.42.0 (build 5f6b62c)", date = "2021-11-09T12:18:40.126Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.SslPolicy")
public enum SslPolicy {
    /**
     * The recommended security policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    RECOMMENDED,
    /**
     * Strong foward secrecy ciphers and TLV1.2 only (2020 edition). Same as FORWARD_SECRECY_TLS12_RES, but only supports GCM versions of the TLS ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12_RES_GCM,
    /**
     * Strong forward secrecy ciphers and TLS1.2 only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12_RES,
    /**
     * Forward secrecy ciphers and TLS1.2 only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12,
    /**
     * Forward secrecy ciphers only with TLS1.1 and higher.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS11,
    /**
     * Forward secrecy ciphers only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY,
    /**
     * TLS1.2 only and no SHA ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS12,
    /**
     * TLS1.2 only with all ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS12_EXT,
    /**
     * TLS1.1 and higher with all ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS11,
    /**
     * Support for DES-CBC3-SHA.
     * <p>
     * Do not use this security policy unless you must support a legacy client
     * that requires the DES-CBC3-SHA cipher, which is a weak cipher.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    LEGACY,
}

==> elasticloadbalancingv2-1.133.0-sources.jar: software/amazon/awscdk/services/elasticloadbalancingv2/SslPolicy.java <==
package software.amazon.awscdk.services.elasticloadbalancingv2;

/**
 * Elastic Load Balancing provides the following security policies for Application Load Balancers.
 * <p>
 * We recommend the Recommended policy for general use. You can
 * use the ForwardSecrecy policy if you require Forward Secrecy
 * (FS).
 * <p>
 * You can use one of the TLS policies to meet compliance and security
 * standards that require disabling certain TLS protocol versions, or to
 * support legacy clients that require deprecated ciphers.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * import software.amazon.awscdk.services.route53.HostedZone;
 * import software.amazon.awscdk.services.certificatemanager.Certificate;
 * import software.amazon.awscdk.services.elasticloadbalancingv2.SslPolicy;
 * Vpc vpc;
 * Cluster cluster;
 * IHostedZone domainZone = HostedZone.fromLookup(this, "Zone", HostedZoneProviderProps.builder().domainName("example.com").build());
 * ICertificate certificate = Certificate.fromCertificateArn(this, "Cert", "arn:aws:acm:us-east-1:123456:certificate/abcdefg");
 * ApplicationLoadBalancedFargateService loadBalancedFargateService = ApplicationLoadBalancedFargateService.Builder.create(this, "Service")
 *         .vpc(vpc)
 *         .cluster(cluster)
 *         .certificate(certificate)
 *         .sslPolicy(SslPolicy.RECOMMENDED)
 *         .domainName("api.example.com")
 *         .domainZone(domainZone)
 *         .redirectHTTP(true)
 *         .taskImageOptions(ApplicationLoadBalancedTaskImageOptions.builder()
 *                 .image(ContainerImage.fromRegistry("amazon/amazon-ecs-sample"))
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see https://docs.aws.amazon.com/elasticloadbalancing/latest/application/create-https-listener.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.45.0 (build 61747b6)", date = "2021-11-19T21:31:11.763Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.elasticloadbalancingv2.$Module.class, fqn = "@aws-cdk/aws-elasticloadbalancingv2.SslPolicy")
public enum SslPolicy {
    /**
     * Forward secrecy ciphers only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY,
    /**
     * Forward secrecy ciphers only with TLS1.1 and higher.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS11,
    /**
     * Forward secrecy ciphers and TLS1.2 only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12,
    /**
     * Strong forward secrecy ciphers and TLS1.2 only.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12_RES,
    /**
     * Strong foward secrecy ciphers and TLV1.2 only (2020 edition). Same as FORWARD_SECRECY_TLS12_RES, but only supports GCM versions of the TLS ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    FORWARD_SECRECY_TLS12_RES_GCM,
    /**
     * Support for DES-CBC3-SHA.
     * <p>
     * Do not use this security policy unless you must support a legacy client
     * that requires the DES-CBC3-SHA cipher, which is a weak cipher.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    LEGACY,
    /**
     * The recommended security policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    RECOMMENDED,
    /**
     * TLS1.1 and higher with all ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS11,
    /**
     * TLS1.2 only and no SHA ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS12,
    /**
     * TLS1.2 only with all ciphers.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    TLS12_EXT,
}
